package fabbroniko.testrawvideofile;

import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;

import java.io.IOException;
import java.io.InputStream;

public class MainActivity extends AppCompatActivity implements SurfaceHolder.Callback{

    private InputStream inputStream = null;
    private DecoderThread decoderThread;
    private boolean initialized = false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        SurfaceHolder surfaceHolder;

        try {
            inputStream = getResources().openRawResource(getResources().getIdentifier("sample_video", "raw", getPackageName()));
            if(inputStream == null) {
                showMessage("File non trovato (restituito null).");
                System.exit(1);
            }else{
                showMessage("File trovato e caricato con successo.");
            }
        }catch (final Exception e) {
            showMessage("Impossibile aprire il file video.");
            e.printStackTrace();
            System.exit(1);
        }

        surfaceHolder = ((SurfaceView)findViewById(R.id.surfaceView)).getHolder();
        surfaceHolder.addCallback(this);
        decoderThread = new DecoderThread();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        try {
            inputStream.close();
            showMessage("File chiuso con successo.");
        } catch (final IOException e) {
            showMessage("Impossibile chiudere il file.");
            e.printStackTrace();
            System.exit(1);
        }
    }

    public static void showMessage(final String msg) {
        Log.d("MyDebugging", msg);
    }

    @Override
    public void surfaceCreated(SurfaceHolder holder) {}

    @Override
    public void surfaceChanged(SurfaceHolder holder, int format, int width, int height) {
        if(decoderThread != null && !initialized) {
            showMessage("SurfaceChanged");
            initialized = true;
            decoderThread.init(holder.getSurface() /*, inputStream */);
        }else{
            throw new IllegalStateException("DecoderThread non dovrebbe essere null.");
        }
    }

    @Override
    public void surfaceDestroyed(SurfaceHolder holder) {
        if(decoderThread != null)
            decoderThread.close();
        else
            throw new IllegalStateException("DecoderThread non dovrebbe essere null.");
    }
}
