package fabbroniko.testrawvideofile.h264;

import java.io.IOException;

public interface CodecH264 {

	/**
	 * Preleva la prossima NAL Unit disponibile dallo stream.
	 * @return Restituisce null nel caso in cui non sia disponibile, altrimenti l'array di byte contenente la NAL Unit.
	 */
	byte[] getNextNALUnit();

	/** Controlla se la NAL unit di tipo SPS è disponibile o meno.
	 *  @return Restituisce true se disponibile, altrimenti false.
	 */
	boolean isSPSAvailable();

	/** Preleva, se disponibile, la NAL Unit di tipo SPS.
	 *  @return Restituisce l'array di byte contenente il Sequence Parameter Set.
	 */
	byte[] getSPSNALUnit();

	/** Controlla se la NAL unit di tipo PPS è disponibile o meno.
	 *  @return Restituisce true se disponibile, altrimenti false.
	 */
	boolean isPPSAvailable();

    /** Preleva, se disponibile, la NAL Unit di tipo PPS.
     *  @return Restituisce l'array di byte contenente il Picture Parameter Set.
     */
	byte[] getPPSNALUnit();
	
	/** Controlla se saranno successivamente disponibili altre NAL Units.
	 *  @return Restituisce true se non saranno più disponibili dati dallo stream, altrimenti false.
	 */
	boolean isStreamClosed();

	/** Chiude lo streaming video.
	 *
	 */
	void closeStream();
}
