package fabbroniko.testrawvideofile.h264;

/**
 *  Fornisce una interfaccia per classi che definiscono un array dinamico di bytes.
 * 	Le modalità di espansione dell'array e la grandezza di default iniziale sono lasciate alle classi che implementeranno questa interfaccia.
 */
public interface DynamicByteArray {

    /**
     * Inserisce un singolo byte nella struttura.
     * @param b Il byte da inserire.
     */
	void put(final byte b);

    /**
     * Inserisce un array di bytes nella struttura.
     * @param b L'array di bytes da inserire.
     */
	void put(final byte[] b);

    /**
     * Inserisce nella struttura il numero di bytes specificato in length a partire dalla posizione offset dell'array b.
     * @param b L'array che si vuole copiare all'interno della struttura dati.
     * @param offset La posizione di partenza da cui copiare i dati.
     * @param length Il numero di bytes da copiare
     * @throws IllegalArgumentException Lanciata se offset o offset + length sono fuori range dell'array.
     */
	void put(final byte[] b, final int offset, final int length) throws IllegalArgumentException;

    /**
     *  Ripristina lo stato iniziale. Rimane alla classe la decisione di resettare la dimensione corrente del buffer o meno.
     */
	void clear();

    /**
     * Restituisce l'array finale composto da più chiamate put.
     * @return L'array costruito.
     */
	byte[] array();
}
